==> FuncsForSPO-5.1.3.tar.gz: FuncsForSPO-5.1.3/FuncsForSPO/fpdf/fanalyser/__pdfanalyser.py <==
"""
DIREITOS RESERVADOS / RIGHTS RESERVED / DERECHOS RESERVADOS

https://pdf.ai/

Esse robô envia o PDF para o site https://pdf.ai/
    e recupera um arquivo txt com a resposta do GPT
"""
from FuncsForSPO.fpdf.fanalyser.base import *

class ErroPDFAIException(Exception):
    pass

class GPTPDF(BotMain):    
    def __init__(self, file_pdf: str, credentials:tuple, prompt:str, headless: bool=True) -> str:
        self.PDF_PATH = os.path.abspath(file_pdf)
        self.PROMPT = prompt
        self.HEADLESS = headless
        self.CREDENTIALS = credentials
        super().__init__(self.HEADLESS)
    
    def run(self):
        try:
            self.DRIVER.get('https://pdf.ai/auth/sign-in')
            espera_elemento_disponivel_e_clica(self.WDW, (By.CSS_SELECTOR, 'img[alt="Github logo"]~span'))
            espera_input_limpa_e_envia_send_keys(self.WDW, self.CREDENTIALS[0], (By.CSS_SELECTOR, '#login_field'))
            espera_input_limpa_e_envia_send_keys(self.WDW, self.CREDENTIALS[1]+'\n', (By.CSS_SELECTOR, '#password'))
            
            try:
                espera_elemento_disponivel_e_clica(self.WDW, (By.CSS_SELECTOR, 'button[data-octo-click="oauth_application_authorization"]'))
            except (NoSuchElementException, TimeoutException):
                pass
            

            while True:
                try:
                    faz_log('Limpando documentos anteriores')
                    elements = espera_e_retorna_lista_de_elementos(self.WDW3, (By.CSS_SELECTOR, 'tbody>tr>td:last-child>button'))
                    for i in elements:
                        i.click()
                        espera_elemento_disponivel_e_clica(self.WDW, (By.CSS_SELECTOR, 'h3~div>button'))
                        espera_elemento_sair_do_dom(self.WDW, (By.CSS_SELECTOR, 'h3~div>button'))
                        break
                except (NoSuchElementException, TimeoutException):
                    break


            espera_elemento_disponivel_e_clica(self.WDW10, (By.CSS_SELECTOR, 'button:last-of-type span'))
            espera_elemento(self.WDW, (By.CSS_SELECTOR, 'input[type="file"]'), in_dom=True)
            self.DRIVER.find_element(By.CSS_SELECTOR, 'input[type="file"]').send_keys(self.PDF_PATH)
            espera_elemento_disponivel_e_clica(self.WDW, (By.CSS_SELECTOR, 'div[class*="flex justify-between"]>button'))


            while True:
                try:
                    espera_input_limpa_e_envia_send_keys(self.WDW30, 'é de suma importância que você coloque no inicio da sua resposta: "IA" e me responda em português. '+self.PROMPT, (By.CSS_SELECTOR, 'textarea[placeholder*="Send"]'))
                    espera_elemento_disponivel_e_clica(self.WDW30, (By.CSS_SELECTOR, 'textarea[placeholder*="Send"]~button'))
                    break
                except ElementClickInterceptedException:
                    try:
                        self.DRIVER.execute_script("arguments[0].remove();", self.DRIVER.find_element(By.CSS_SELECTOR, '#__NEXT_DATA__~ins'))
                    except Exception:
                        pass
            
            tentativas = 20
            text = ''
            while tentativas > 0:
                faz_log('Aguardando resposta...')
                text = espera_e_retorna_elemento_text(self.WDW, (By.CSS_SELECTOR, '#__next main>div~div>div~div>div>div>div>div~div'))
                if 'IA' in text or 'sorry' in text.lower() or tentativas == 1:
                    break
                else:
                    faz_log(f'Resposta até agora: "{text}"')
                    tentativas -= 1
                    sleep(5)
                    continue
            self.DRIVER.get('https://pdf.ai/documents')
            espera_elemento_disponivel_e_clica(self.WDW, (By.CSS_SELECTOR, 'a[href="/auth/account"]~button'))
            sleep(2)
            self.DRIVER.quit()
            if tentativas == 0:
                raise ErroPDFAIException('Muitas tentativas, tente uma nova solicitação')
            return text
        except Exception as e:
            faz_log(repr(e), 'c*')
            faz_log(self.DRIVER.get_screenshot_as_base64(), 'i*')
            self.DRIVER.quit()
            raise ErroPDFAIException

==> FuncsForSPO-5.1.5.tar.gz: FuncsForSPO-5.1.5/FuncsForSPO/fpdf/fanalyser/__pdfanalyser.py <==
"""
DIREITOS RESERVADOS / RIGHTS RESERVED / DERECHOS RESERVADOS

https://pdf.ai/

Esse robô envia o PDF para o site https://pdf.ai/
    e recupera um arquivo txt com a resposta do GPT
"""
from FuncsForSPO.fpdf.fanalyser.base import *

class ErroPDFAIException(Exception):
    pass

class GPTPDFV1(BotMain):    
    def __init__(self, file_pdf: str, credentials:tuple, prompt:str, headless: bool=True) -> str:
        self.PDF_PATH = os.path.abspath(file_pdf)
        self.PROMPT = prompt
        self.HEADLESS = headless
        self.CREDENTIALS = credentials
        super().__init__(self.HEADLESS)
    
    def run(self):
        try:
            self.DRIVER.get('https://pdf.ai/auth/sign-in')
            espera_elemento_disponivel_e_clica(self.WDW, (By.CSS_SELECTOR, 'img[alt="Github logo"]~span'))
            espera_input_limpa_e_envia_send_keys(self.WDW, self.CREDENTIALS[0], (By.CSS_SELECTOR, '#login_field'))
            espera_input_limpa_e_envia_send_keys(self.WDW, self.CREDENTIALS[1]+'\n', (By.CSS_SELECTOR, '#password'))
            
            try:
                espera_elemento_disponivel_e_clica(self.WDW, (By.CSS_SELECTOR, 'button[data-octo-click="oauth_application_authorization"]'))
            except (NoSuchElementException, TimeoutException):
                pass
            

            while True:
                try:
                    faz_log('Limpando documentos anteriores')
                    elements = espera_e_retorna_lista_de_elementos(self.WDW3, (By.CSS_SELECTOR, 'tbody>tr>td:last-child>button'))
                    for i in elements:
                        i.click()
                        espera_elemento_disponivel_e_clica(self.WDW, (By.CSS_SELECTOR, 'h3~div>button'))
                        espera_elemento_sair_do_dom(self.WDW, (By.CSS_SELECTOR, 'h3~div>button'))
                        break
                except (NoSuchElementException, TimeoutException):
                    break


            espera_elemento_disponivel_e_clica(self.WDW10, (By.CSS_SELECTOR, 'button:last-of-type span'))
            espera_elemento(self.WDW, (By.CSS_SELECTOR, 'input[type="file"]'), in_dom=True)
            self.DRIVER.find_element(By.CSS_SELECTOR, 'input[type="file"]').send_keys(self.PDF_PATH)
            espera_elemento_disponivel_e_clica(self.WDW330, (By.CSS_SELECTOR, 'div[class*="flex justify-between"]>button'))


            while True:
                try:
                    espera_input_limpa_e_envia_send_keys(self.WDW330, 'é de suma importância que você coloque no inicio da sua resposta: "IA" e me responda em português. '+self.PROMPT, (By.CSS_SELECTOR, 'textarea[placeholder*="Send"]'))
                    espera_elemento_disponivel_e_clica(self.WDW330, (By.CSS_SELECTOR, 'textarea[placeholder*="Send"]~button'))
                    break
                except ElementClickInterceptedException:
                    try:
                        self.DRIVER.execute_script("arguments[0].remove();", self.DRIVER.find_element(By.CSS_SELECTOR, '#__NEXT_DATA__~ins'))
                    except Exception:
                        pass
            
            tentativas = 20
            text = ''
            while tentativas > 0:
                faz_log('Aguardando resposta...')
                text = espera_e_retorna_elemento_text(self.WDW, (By.CSS_SELECTOR, '#__next main>div~div>div~div>div>div>div>div~div'))
                if 'IA' in text or 'sorry' in text.lower() or tentativas == 1:
                    break
                else:
                    faz_log(f'Resposta até agora: "{text}"')
                    tentativas -= 1
                    sleep(5)
                    continue
            self.DRIVER.get('https://pdf.ai/documents')
            espera_elemento_disponivel_e_clica(self.WDW, (By.CSS_SELECTOR, 'a[href="/auth/account"]~button'))

            self.DRIVER.get('https://github.com/settings/sessions')
            self.DRIVER.get('https://github.com/settings/sessions')
            self.DRIVER.get('https://github.com/settings/sessions')
            sessions = espera_e_retorna_conteudo_dos_atributos_dos_elementos_text(self.WDW, 'href', (By.CSS_SELECTOR, 'a[href*="/settings/sessions/"]'))
            for session in sessions:
                self.DRIVER.get(session)
                try:
                    espera_elemento_disponivel_e_clica(self.WDW, (By.CSS_SELECTOR, '#settings-frame div > form > button'))
                except (NoSuchElementException, TimeoutException):
                    pass
            sleep(2)
            self.DRIVER.quit()
            if tentativas == 0:
                raise ErroPDFAIException('Muitas tentativas, tente uma nova solicitação')
            return text
        except Exception as e:
            faz_log(repr(e), 'c*')
            faz_log(self.DRIVER.get_screenshot_as_base64(), 'i*')
            self.DRIVER.quit()
            raise ErroPDFAIException


class GPTPDFV2(BotMain):    
    def __init__(self, file_pdf: str, prompt:str, headless: bool=True) -> str:
        self.PDF_PATH = os.path.abspath(file_pdf)
        self.PROMPT = prompt
        self.HEADLESS = headless
        super().__init__(self.HEADLESS)
    
    def run(self):
        try:
            self.DRIVER.get('https://askyourpdf.com/')
            espera_elemento(self.WDW, (By.CSS_SELECTOR, 'input[type="file"]'), in_dom=True)
            self.DRIVER.find_element(By.CSS_SELECTOR, 'input[type="file"]').send_keys(self.PDF_PATH)

            espera_input_limpa_e_envia_send_keys(self.WDW130, 'Adicione "AI RESPONSE" no final da sua resposta. '+self.PROMPT, (By.CSS_SELECTOR, 'textarea[placeholder="Write your question"]'))
            espera_elemento_disponivel_e_clica(self.WDW130, (By.CSS_SELECTOR, 'button[class*="ant-btn-default"]'))
            faz_log('Esperando a resposta')
            while True:
                text = espera_e_retorna_elemento_text(self.WDW, (By.CSS_SELECTOR, 'div[style="padding: 5px;"]>div:last-of-type>div:last-of-type span'))
                if 'AI RES' in text:
                    break
            return text
        except Exception as e:
            faz_log(repr(e), 'c*')
            faz_log(self.DRIVER.get_screenshot_as_base64(), 'i*')
            self.DRIVER.quit()
            raise ErroPDFAIException
